@@ -1,8 +1,8 @@
 import abc
-from typing import Type
-
+from typing import Type, List
 from pydantic import BaseModel
 
+from pymultirole_plugins.v1 import ABCSingleton
 from pymultirole_plugins.v1.schema import Document
 
 
@@ -10,7 +10,7 @@ class AnnotatorParameters(BaseModel):
     pass
 
 
-class AnnotatorBase(metaclass=abc.ABCMeta):
+class AnnotatorBase(metaclass=ABCSingleton):
     """Base class for example plugin used in the tutorial.
     """
 
@@ -18,9 +18,9 @@ class AnnotatorBase(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def annotate(self, document: Document, options: AnnotatorParameters) \
-            -> Document:
-        """Annotate the input document and return a modified document.
+    def annotate(self, documents: List[Document], options: AnnotatorParameters) \
+            -> List[Document]:
+        """Annotate the input documents and return the modified documents.
 
         :param document: An annotated document.
         :param options: options of the parser.
