@@ -4,6 +4,7 @@ from pydantic import BaseModel
 from starlette.datastructures import UploadFile
 
 from pymultirole_plugins.schema import FormDataModel
+from pymultirole_plugins.v1 import ABCSingleton
 from pymultirole_plugins.v1.schema import Document
 
 
@@ -11,7 +12,7 @@ class ConverterParameters(FormDataModel):
     pass
 
 
-class ConverterBase(metaclass=abc.ABCMeta):
+class ConverterBase(metaclass=ABCSingleton):
     """Base class for example plugin used in the tutorial.
     """
 
